import os
import time
import threading
import queue
from random import randint as rand
try:
    import sys
    import select
    import tty
    import termios
    tty.setcbreak(sys.stdin.fileno())
    def getchar():
        if select.select([sys.stdin], [], [], 0) == ([sys.stdin], [], []):
            c = sys.stdin.read(1)
            if c == "\033":
                sys.stdin.read(1)
                return sys.stdin.read(1)
            return c
        return None
except:
    from msvcrt import getch, kbhit
    def getchar():
        if kbhit():
            c = getch()
            if c == "\033":
                getch()
                return getch()
            return c
        else:
            return None

WAIT = 0.3
TIME_LAST = time.time()

def gen(c1, c2, l):
    return "\033[1;3" + str(c1) + ";4" + str(c2) + "m" + l + "\033[0m"

class Field:
    def __init__(self, n, m):
        self.field = [[gen(7, 0, ' ') for j in range(n)] for i in range(m)]
        cx = m // 3
        self.hums = 0
        self.hums_boat = 0
        xrand = rand(0, 4)
        for i in range(n):
            for j in range(0, cx + 1):
                self.field[m - j - 1][i] = gen([1, 1, 3, 7, 7][rand(0, 4)], 5, '#')
            if rand(0, 10) == 0:
                self.hums += 1
                self.field[m - cx - 2][i] = gen(3, 0, 'y')
            else:
                self.field[m - cx - 2][i] = gen(2, 0, '/\\'[rand(0, 1)])
            cx += rand(-2, 2)
            if cx > m // 2:
                cx = m // 2
            elif cx < 0:
                cx = 0
            if xrand >= 3 and cx < 6:
                cx = 6
        
        if xrand >= 3:
            y = rand(2, len(self.field[0]) // 3)
            ymax = rand(2 * len(self.field[0]) // 3, len(self.field[0]) - 2)
            g = 0
            gx = len(self.field) - rand(0, 1) * 5 - 1
            while y < ymax:
                if xrand == 4:
                    if gx != len(self.field) - 2:
                        gx = len(self.field) - 2
                    else:
                        gx = len(self.field) - rand(1, 5) - 1
                else:
                    gx += rand(-1, 1)
                    if gx > len(self.field) - 2:
                        gx = len(self.field) - 2
                    elif gx < len(self.field) - 6:
                        gx = len(self.field) - 6
                if y == ymax - 1:
                    gx = 0
                tdo = (rand(0, 2) == 0) or xrand == 3
                while g > gx:
                    g -= 1
                    if self.field[g][y] == gen(3, 0, 'y'):
                        self.hums -= 1
                    if g > len(self.field) - 7 and tdo:
                        self.field[g][y] = gen(2, 0, '/\\'[rand(0, 1)])
                    else:
                        self.field[g][y] = gen(7, 0, ' ')
                while g < gx:
                    g += 1
                    if self.field[g][y] == gen(3, 0, 'y'):
                        self.hums -= 1
                    if g > len(self.field) - 7 and tdo:
                        self.field[g][y] = gen(2, 0, '/\\'[rand(0, 1)])
                    else:
                        self.field[g][y] = gen(7, 0, ' ')
                y += 1
                if self.field[g][y] == gen(3, 0, 'y'):
                    self.hums -= 1
                if g > len(self.field) - 7 and xrand == 3:
                    self.field[g][y] = gen(2, 0, '/\\'[rand(0, 1)])
                else:
                    self.field[g][y] = gen(7, 0, ' ')
            for i in range(len(self.field[0])):
                j = len(self.field) - 1
                while j > len(self.field) - 6 and not self.field[j][i] in [gen(2, 0, '/'), gen(2, 0, '\\'), gen(7, 0, ' ')]:
                    j -= 1
                if j != len(self.field) - 6:
                    if rand(0, 30 // (xrand - 2)) == 0:
                        self.hums += 1
                        self.field[j][i] = gen(3, 0, 'y')
                tneed = False
                for j in range(len(self.field) - 6, len(self.field)):
                    if self.field[j][i] in [gen(2, 0, '/'), gen(2, 0, '\\')]:
                        tneed = True
                    if self.field[j][i] == gen(7, 0, ' ') and tneed:
                        self.field[j][i] = gen(2, 0, '/\\'[rand(0, 1)])
        self.hums_begin = self.hums
        self.time = time.time() + (int((n + m) * WAIT * (self.hums + 2) / 1.5) // 10) * 6
        for i in range(n):
            self.field[1][i] = gen(7, 4, '-')
        self.field[1][len(self.field[0]) // 2] = gen(7, 0, ' ')
        self.boat_pos = (1, len(self.field[0]) // 2)
        self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(7, 0, 'b')
        self.boat_speed = (0, 0)
        self.spruts_pos = []
        for i in range(7):
            r, c = rand(2, len(self.field) - 1), rand(0, len(self.field[0]) - 1)
            while not self.field[r][c] in [gen(7, 0, ' '), gen(2, 0, '/'), gen(2, 0, '\\')]:
                r, c = rand(2, len(self.field) - 1), rand(0, len(self.field[0]) - 1)
            self.spruts_pos.append((r, c, i))
            if self.field[r][c] == gen(7, 0, ' '):
                self.field[r][c] = gen(i + 1, 0, 'W')
        self.moving = (0, 0)
        self.go = True
        self.ai = False
    def move(self, pos):
        if self.moving != (0, 0) and self.moving == (-pos[0], -pos[1]):
            self.moving = (0, 0)
        elif self.moving == (0, 0):
            self.moving = pos
    def exit(self):
        self.go = False
def move_spruts(self):
    d_pos = [(1, 0), (-1, 0), (0, 1), (0, -1)]
    for i in range(len(self.spruts_pos)):
        p = d_pos[rand(0, 3)]
        p_old = (self.spruts_pos[i][0], self.spruts_pos[i][1])
        if "M" in self.field[p_old[0]][p_old[1]] or "X" in self.field[p_old[0]][p_old[1]]:
            continue
        p = (self.spruts_pos[i][0] + p[0], self.spruts_pos[i][1] + p[1])
        while not (2 <= p[0] < len(self.field) and 0 <= p[1] < len(self.field[0])):
            p = d_pos[rand(0, 3)]
            p = (self.spruts_pos[i][0] + p[0], self.spruts_pos[i][1] + p[1])
        if self.field[p_old[0]][p_old[1]] in [gen(2, 0, '/'), gen(2, 0, '\\')]:
            if self.field[p[0]][p[1]] == gen(7, 0, ' '):
                self.spruts_pos[i] = (p[0], p[1], self.spruts_pos[i][2])
                self.field[p[0]][p[1]] = gen(self.spruts_pos[i][2] + 1, 0, 'W')
            elif self.field[p[0]][p[1]] in [gen(2, 0, '/'), gen(2, 0, '\\')]:
                self.spruts_pos[i] = (p[0], p[1], self.spruts_pos[i][2])
        else:
            if self.field[p[0]][p[1]] == gen(7, 0, ' '):
                self.spruts_pos[i] = (p[0], p[1], self.spruts_pos[i][2])
                self.field[p_old[0]][p_old[1]] = gen(7, 0, ' ')
                self.field[p[0]][p[1]] = gen(self.spruts_pos[i][2] + 1, 0, 'W')
            elif self.field[p[0]][p[1]] in [gen(2, 0, '/'), gen(2, 0, '\\')]:
                self.spruts_pos[i] = (p[0], p[1], self.spruts_pos[i][2])
                self.field[p_old[0]][p_old[1]] = gen(7, 0, ' ')
def game_over(self, sz1):
    global TIME_LAST
    for i in self.spruts_pos:
        self.field[i[0]][i[1]] = gen(i[2] + 1, 0, "W")
    tm = int(self.time - time.time() + 0.999)
    sz_time = (str(tm // 60).rjust(2, '0') + ':' + str(tm % 60).rjust(2, '0')).rjust(5)
    if not self.ai:
        for u in range(len(sz_time)):
            self.field[0][1 + u] = gen(7, 0, sz_time[u])
    else:
        for u in range(len(sz_time)):
            self.field[0][4 + u] = gen(7, 0, sz_time[u])
        self.field[0][1] = gen(0, 7, 'A')
        self.field[0][2] = gen(0, 7, 'I')
        self.field[0][3] = gen(7, 0, ' ')
    while self.go:
        move_spruts(self)
        t_k = True
        for i in range(len(self.field)):
            for j in range(len(self.field[0])):
                if self.field[i][j] == gen(2, 0, '/'):
                    self.field[i][j] = gen(2, 0, '\\')
                elif self.field[i][j] == gen(2, 0, '\\'):
                    self.field[i][j] = gen(2, 0, '/')
                elif self.field[i][j] in [gen(3, 0, 'y'), gen(3, 0, 'Y')]:
                    self.field[i][j] = gen(1, 0, '*')
                elif self.field[i][j] == gen(3, 0, 'I') and t_k:
                    t_k = False
                    k = 1
                    while j + k < len(self.field[0]) - 1 and self.field[i][j + k] == gen(3, 0, 'I'):
                        k += 1
                    if j + k != len(self.field[0]) - 1:
                        self.field[i][j + k] = gen(3, 0, 'I')
                        self.field[i][j] = gen(7, 0, ' ')
                elif self.field[i][j] == gen(7, 0, '['):
                    self.field[i][j] = gen(7, 0, ' ')
                    if j != 0 and self.field[i][j - 1] == gen(7, 0, ' '):
                        self.field[i][j - 1] = gen(7, 0, '[')
                    elif j != 0 and 'W' in self.field[i][j - 1]:
                        self.field[i][j - 1] = self.field[i][j - 1].replace('W', 'M')
                    elif j != 0 and self.field[i][j - 1] == gen(7, 0, 'b'):
                        self.field[i][j - 1] = gen(7, 0, 'p')
                elif self.field[i][j] == gen(7, 0, 'p'):
                    self.field[i][j] = gen(7, 0, 'g')
                elif self.field[i][j] == gen(7, 0, 'g'):
                    self.field[i][j] = gen(7, 0, 'b')
                elif 'M' in self.field[i][j]:
                    self.field[i][j] = self.field[i][j].replace('M', 'X')
                elif 'X' in self.field[i][j]:
                    self.field[i][j] = self.field[i][j].replace('X', 'W')
        sz = "Press ENTER or R to start the game"
        for u in range(len(sz1)):
            self.field[len(self.field) // 3][6 + u] = gen(7, 0, sz1[u])
        for u in range(len(sz)):
            self.field[len(self.field) // 3 + 2][3 + u] = gen(7, 0, sz[u])
        print("\033[0;0;H")
        for row in self.field[:-1]:
            print(''.join(row))
        print(end = ''.join(self.field[-1]))
        os.sys.stdout.flush()
        if time.time() - TIME_LAST < WAIT:
            time.sleep(abs(WAIT - (time.time() - TIME_LAST)))
        TIME_LAST = time.time()
    return 0
def show(self, run = False):
    global TIME_LAST
    if not run:
        tm = int(self.time - time.time() + 0.999)
        sz_time = (str(tm // 60).rjust(2, '0') + ':' + str(tm % 60).rjust(2, '0')).rjust(5)
        for u in range(len(sz_time)):
            self.field[0][1 + u] = gen(7, 0, sz_time[u])
        
        while self.go:
            move_spruts(self)
            for i in range(len(self.field)):
                for j in range(len(self.field[0])):
                    if self.field[i][j] == gen(2, 0, '/'):
                        self.field[i][j] = gen(2, 0, '\\')
                    elif self.field[i][j] == gen(2, 0, '\\'):
                        self.field[i][j] = gen(2, 0, '/')
                    elif self.field[i][j] == gen(3, 0, 'y') and rand(0, 2) == 0:
                        self.field[i][j] = gen(3, 0, 'Y')
                    elif self.field[i][j] == gen(3, 0, 'Y'):
                        self.field[i][j] = gen(3, 0, 'y')
            sz = "THE SPRUTS"
            for u in range(len(sz)):
                self.field[1][len(self.field[0]) // 2 - 4 + u] = gen(7, 0, sz[u])
            sz = "Save all divers   Press ENTER or R to start the game"
            for u in range(len(sz)):
                self.field[len(self.field) // 3 - 3][3 + u] = gen(7, 0, sz[u])
            sz = "h - left; j - down; k - up; l - right; q - exit; a - help of ai"
            for u in range(len(sz)):
                self.field[len(self.field) // 3][3 + u] = gen(7, 0, sz[u])
            print("\033[0;0;H")
            for row in self.field[:-1]:
                print(''.join(row))
            print(end = ''.join(self.field[-1]))
            os.sys.stdout.flush()
            if time.time() - TIME_LAST < WAIT:
                time.sleep(abs(WAIT - (time.time() - TIME_LAST)))
            TIME_LAST = time.time()
        return 0
    cnt = 1
    cnt_stable = 0
    while self.go:
        if self.hums == 0 and self.hums_boat == 0:
            return game_over(self, "WIN - saved all " + str(self.hums_begin) + " divers")
        if cnt % (len(self.field[0]) * 3) > 2 * len(self.field[0]):
            for i in range(len(self.field) // 3):
                if self.field[rand(2, len(self.field) // 3)][len(self.field[0]) - 1] == gen(7, 0, ' '):
                    self.field[rand(2, len(self.field) // 3)][len(self.field[0]) - 1] = gen(7, 0, '[')
        move_spruts(self)
        tm = int(self.time - time.time() + 0.999)
        sz_time = (str(tm // 60).rjust(2, '0') + ':' + str(tm % 60).rjust(2, '0')).rjust(5)
        if not self.ai:
            for u in range(len(sz_time)):
                self.field[0][1 + u] = gen(7, 0, sz_time[u])
        else:
            for u in range(len(sz_time)):
                self.field[0][4 + u] = gen(7, 0, sz_time[u])
            self.field[0][1] = gen(0, 7, 'A')
            self.field[0][2] = gen(0, 7, 'I')
            self.field[0][3] = gen(7, 0, ' ')
        if tm == 0:
            if self.hums_begin - self.hums - self.hums_boat == 0:
                return game_over(self, "GAME OVER - no saved")
            else:
                return game_over(self, "GAME OVER - saved only " + str(self.hums_begin - self.hums - self.hums_boat) + " divers")
        if True:
            t_k = True
            for i in range(len(self.field)):
                for j in range(len(self.field[0])):
                    if self.field[i][j] == gen(2, 0, '/'):
                        self.field[i][j] = gen(2, 0, '\\')
                    elif self.field[i][j] == gen(2, 0, '\\'):
                        self.field[i][j] = gen(2, 0, '/')
                    elif self.field[i][j] == gen(3, 0, 'y') and rand(0, 2) == 0:
                        self.field[i][j] = gen(3, 0, 'Y')
                    elif self.field[i][j] == gen(3, 0, 'Y'):
                        self.field[i][j] = gen(3, 0, 'y')
                    elif self.field[i][j] == gen(3, 0, 'I') and t_k:
                        t_k = False
                        k = 1
                        while j + k < len(self.field[0]) - 1 and self.field[i][j + k] == gen(3, 0, 'I'):
                            k += 1
                        if j + k != len(self.field[0]) - 1:
                            self.field[i][j + k] = gen(3, 0, 'I')
                            self.field[i][j] = gen(7, 0, ' ')
                    elif self.field[i][j] == gen(7, 0, '['):
                        self.field[i][j] = gen(7, 0, ' ')
                        if j != 0 and self.field[i][j - 1] == gen(7, 0, ' '):
                            self.field[i][j - 1] = gen(7, 0, '[')
                        elif j != 0 and 'W' in self.field[i][j - 1]:
                            self.field[i][j - 1] = self.field[i][j - 1].replace('W', 'M')
                        elif j != 0 and self.field[i][j - 1] == gen(7, 0, 'b'):
                            self.field[i][j - 1] = gen(7, 0, 'p')
                    elif self.field[i][j] == gen(7, 0, 'p'):
                        self.field[i][j] = gen(7, 0, 'g')
                    elif self.field[i][j] == gen(7, 0, 'g'):
                        self.field[i][j] = gen(7, 0, 'b')
                    elif 'M' in self.field[i][j]:
                        self.field[i][j] = self.field[i][j].replace('M', 'X')
                    elif 'X' in self.field[i][j]:
                        self.field[i][j] = self.field[i][j].replace('X', 'W')
        if cnt % 70 == 0:
            for i in range(3, len(self.field)):
                for j in range(len(self.field[0])):
                    if self.field[i][j] == gen(2, 0, '/') and self.field[i - 1][j] == gen(7, 0, ' ') and rand(0, 1):
                        self.field[i - 1][j] = gen(2, 0, '\\')
                    elif self.field[i][j] == gen(2, 0, '\\') and self.field[i - 1][j] == gen(7, 0, ' ') and rand(0, 1):
                        self.field[i - 1][j] = gen(2, 0, '/')

        if cnt_stable % (3 - abs(self.boat_speed[0] + self.boat_speed[1])) == 0:
            cnt_stable = 0
            if (self.boat_speed[0] != 0 and self.moving[0] != 0):
                self.boat_speed = (self.boat_speed[0] + self.moving[0], self.boat_speed[1] + self.moving[1])
            elif (self.boat_speed[1] != 0 and self.moving[1] != 0):
                self.boat_speed = (self.boat_speed[0] + self.moving[0], self.boat_speed[1] + self.moving[1])
            elif self.boat_speed[0] + self.boat_speed[1] == 0:
                self.boat_speed = (self.boat_speed[0] + self.moving[0], self.boat_speed[1] + self.moving[1])
            self.boat_speed = (min(2, max(-2, self.boat_speed[0])), min(2, max(-2, self.boat_speed[1])))
            self.moving = (0, 0)
            addr, addc = 0, 0
            if self.boat_speed[0] != 0:
                addr = self.boat_speed[0] // abs(self.boat_speed[0])
            if self.boat_speed[1] != 0:
                addc = self.boat_speed[1] // abs(self.boat_speed[1])
            if self.field[self.boat_pos[0]][self.boat_pos[1]] == gen(7, 0, 'b'):
                self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(7, 0, ' ')
            elif self.field[self.boat_pos[0]][self.boat_pos[1]] in [gen(7, 0, 'p'), gen(7, 0, 'g')]:
                self.boat_speed = (0, 0)
            else:
                self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(2, 0, "/\\"[rand(0, 1)])
            if 1 <= self.boat_pos[0] + addr < len(self.field) and 0 <= self.boat_pos[1] + addc < len(self.field[0]) and not self.field[self.boat_pos[0]][self.boat_pos[1]] in [gen(7, 0, 'p'), gen(7, 0, 'g')]:
                if self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] == gen(7, 0, ' '):
                    if self.boat_pos[0] + addr == 1:
                        v = len(self.field[0]) // 2 + 1
                        while self.field[0][v] == gen(3, 0, 'I'):
                            v += 1
                        for i in range(self.hums_boat):
                            self.field[0][v] = gen(3, 0, 'I')
                            while self.field[0][v] == gen(3, 0, 'I'):
                                v += 1
                        self.hums_boat = 0
                    self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] = gen(7, 0, 'b')
                elif self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] in [gen(2, 0, '/'), gen(2, 0, '\\')]:
                    t = False
                    for i in self.spruts_pos:
                        if i[0] == self.boat_pos[0] + addr and i[1] == self.boat_pos[1] + addc:
                            t = True
                    if t:
                        self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(7, 0, '*')
                        if self.hums_begin - self.hums - self.hums_boat == 0:
                            return game_over(self, "GAME OVER - no saved")
                        else:
                            return game_over(self, "GAME OVER - saved only " + str(self.hums_begin - self.hums - self.hums_boat) + " divers")
                    else:
                        self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] = gen(2, 0, 'k')
                elif self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] in [gen(3, 0, 'y'), gen(3, 0, 'Y')]:
                    self.hums -= 1
                    self.hums_boat += 1
                    self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] = gen(2, 0, 'k')
                elif self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] == gen(7, 0, '['):
                    self.field[self.boat_pos[0] + addr][self.boat_pos[1] + addc] = gen(7, 0, 'p')
                else:
                    self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(7, 0, '*')
                    if self.hums_begin - self.hums - self.hums_boat == 0:
                        return game_over(self, "GAME OVER - no saved")
                    else:
                        return game_over(self, "GAME OVER - saved only " + str(self.hums_begin - self.hums - self.hums_boat) + " divers")
                self.boat_pos = (self.boat_pos[0] + addr, self.boat_pos[1] + addc)
            elif not self.field[self.boat_pos[0]][self.boat_pos[1]] in [gen(7, 0, 'p'), gen(7, 0, 'g')]:
                self.field[self.boat_pos[0]][self.boat_pos[1]] = gen(7, 0, '*')
                if self.hums_begin - self.hums - self.hums_boat == 0:
                    return game_over(self, "GAME OVER - no saved")
                else:
                    return game_over(self, "GAME OVER - saved only " + str(self.hums_begin - self.hums - self.hums_boat) + " divers")
        print("\033[0;0;H")
        for row in self.field[:-1]:
            print(''.join(row))
        print(end = ''.join(self.field[-1]))
        os.sys.stdout.flush()
        if time.time() - TIME_LAST < WAIT:
            time.sleep(abs(WAIT - (time.time() - TIME_LAST)))
        TIME_LAST = time.time()
        cnt += 1
        cnt_stable += 1

        if self.ai:
            d_move = [(1, 0), (-1, 0), (0, 1), (0, -1)]
            ps = None
            for i in range(2, len(self.field)):
                for j in range(len(self.field[0])):
                    if self.field[i][j] in [gen(3, 0, 'y'), gen(3, 0, 'Y')]:
                        ps = (i, j)
            to_end = (1, len(self.field[0]) // 2)
            q = queue.PriorityQueue()
            rs = dict()
            if ps == None or self.hums_boat >= max(self.hums // 2, 3):
                ps = (1, len(self.field[0]) // 2)
            q.put((0, ps[0], ps[1], (0, 0)))
            cts = (len(self.field) + len(self.field[0])) * 16
            while not q.empty() and cts >= 0:
                cts -= 1
                mq = q.get()
                if not (mq[1], mq[2]) in rs:
                    rs[(mq[1], mq[2])] = mq[3]
                    if (mq[1], mq[2]) == self.boat_pos:
                        break
                    for x in d_move:
                        i, j = mq[1] + x[0], mq[2] + x[1]
                        if 1 <= i < len(self.field) and 0 <= j < len(self.field[0]):
                            if self.field[i][j] in [gen(7, 0, ' '), gen(2, 0, '/'), gen(2, 0, '\\'), gen(3, 0, 'y'), gen(3, 0, 'Y'), gen(7, 0, 'b'), gen(2, 0, 'k')]:
                                q.put(((i - self.boat_pos[0]) ** 2 + (j - self.boat_pos[1]) ** 2, i, j, (-x[0], -x[1])))
            if self.boat_pos in rs:
                if rs[self.boat_pos] == self.boat_speed:
                    if rand(0, 3) == 0:
                        self.boat_speed = (rs[self.boat_pos][0] * 2, rs[self.boat_pos][1] * 2)
                elif not (rs[self.boat_pos][0] * 2 == self.boat_speed[0] and rs[self.boat_pos][1] * 2 == self.boat_speed[1]):
                    self.boat_speed = rs[self.boat_pos]
            else:
                self.boat_speed = (0, 0)
            for i in range(-2, 3):
                for j in range(-2, 3):
                    if 2 <= self.boat_pos[0] + i < len(self.field) and 0 <= self.boat_pos[1] + j < len(self.field[0]) and abs(i) + abs(j) <= 2:
                        if 'W' in self.field[self.boat_pos[0] + i][self.boat_pos[1] + j]:
                            self.boat_speed = (0, 0)

print("\033[J")
field = Field(*os.get_terminal_size())

def dokey(key):
    global field
    if key == 'q':
        field.exit()
        os.system("stty echo && tput cnorm")
        exit()
    elif key == 'r' or key == "\n":
        field.exit()
        print("\033[J")
        field = Field(*os.get_terminal_size())
        thr_field = threading.Thread(target = lambda: show(field, True))
        thr_field.isDaemon = False
        thr_field.start()
        time.sleep(WAIT)
    elif key == 'k' or key == 'A':
        field.move((-1, 0))
    elif key == 'j' or key == 'B':
        field.move((1, 0))
    elif key == 'l' or key == 'C':
        field.move((0, 1))
    elif key == 'h' or key == 'D':
        field.move((0, -1))
    elif key == 'a':
        field.ai = True

def readbutton():
    while True:
        key = getchar()
        dokey(key)
        time.sleep(WAIT / 10)

os.system("stty -echo && tput civis")
thr_keyboard = threading.Thread(target = readbutton)
thr_keyboard.isDaemon = False
thr_keyboard.start()

show(field)
